"""Building blocks namespace for gaik components (extractor, transcriber, parsers, doc_classifier, config)."""

__all__ = [
    "config",
    "extractor",
    "transcriber",
    "parsers",
    "doc_classifier",
]
