"""
Documents (PDF/images/DOCX) to structured data pipeline: parse + extract.
"""

from .pipeline import DocumentsToStructuredData, PipelineResult

__all__ = ["DocumentsToStructuredData", "PipelineResult"]
