export function InstallSnippet() {
  return (
    <section className="mx-auto mt-16 max-w-2xl text-center">
      <h2 className="mb-4 text-2xl font-semibold">Quick Install</h2>
      <div className="rounded-lg bg-muted p-4 font-mono text-sm">
        pip install gaik[all]
      </div>
    </section>
  );
}
